@@ -12,7 +12,7 @@ from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.2.1'
+VERSION = '0.2.2'
 
 default_backliftURL = 'https://www.backlift.com/'
 backlift_configfile = '.backlift'
@@ -62,6 +62,7 @@ ERR_NOURL =    "Oops! This app doesn't have a valid URL. Have you pushed\n"+\
                "have pushed your app and you're still getting this error,\n"+\
                "please let us know by sending an email to %s." % backlift_email
 
+ERR_NOUSER =   "Oops! User couldn't be created."
 
 ## UTILITIES ------------------------------------------------------------------
 
@@ -245,6 +246,25 @@ def create_app(api_key):
     return None
 
 
+def create_superuser(api_key, app_id, username, password):
+    try:
+        # import pdb; pdb.set_trace()
+        data={'username': username, 'password': password}
+        headers = {'x-requested-with': 'BackliftAPI'}
+        res = requests.post(backliftURL_createsuperuser % app_id, 
+                          auth=HTTPBasicAuth('api', api_key), verify=False,
+                          headers=headers, data=data)
+        check_response(res)
+
+        res = json.loads(res.text)
+        return res['_id']
+
+    except requests.exceptions.ConnectionError:
+        fail(ERR_SERVER)
+
+    return None
+
+
 def download_template_files(path, template, api_key, params=None):
     files = []
     try:
@@ -416,6 +436,21 @@ def open_browser(path, admin=False):
 
     webbrowser.open_new_tab(url)
 
+def make_su(path, username, password):
+
+    # import pdb; pdb.set_trace()
+
+    api_key = read_api_key()
+
+    cfg_path = os.path.normpath(os.path.abspath(
+        os.path.join(path, backlift_configfile)))
+
+    app_id = get_id(cfg_path)
+
+    userid = create_superuser(api_key, app_id, username, password)
+
+    if not userid:
+        fail(ERR_NOUSER)
 
 ## MAIN -----------------------------------------------------------------------
 
@@ -427,6 +462,7 @@ def execute_command_line():
     global backliftURL_createapp
     global backliftURL_templatefiles
     global backliftURL_upload
+    global backliftURL_createsuperuser
 
     usagetxt = '%prog COMMAND [options]\n\n' +\
         'Commands:\n' +\
@@ -437,7 +473,8 @@ def execute_command_line():
         '  push\t\t\tPush files up to backlift\n' +\
         '  watch\t\t\tObserve path and push files to backlift whenever they change\n' +\
         '  open\t\t\tOpen an app using the default browser\n' +\
-        '  admin\t\t\tOpen an app\'s admin page using the default browser'
+        '  admin\t\t\tOpen an app\'s admin page using the default browser\n' +\
+        '  makesuperuser NAME PASSWORD\tCreate a super user with the given name / password.'
 
     parser = optparse.OptionParser(usagetxt, version='%prog cli '+VERSION)
 
@@ -458,6 +495,7 @@ def execute_command_line():
     backliftURL_createapp = os.path.join(backliftURL, 'app-admin')
     backliftURL_templatefiles = os.path.join(backliftURL, 'app-templates')
     backliftURL_upload = os.path.join(backliftURL, 'app-admin/%s')
+    backliftURL_createsuperuser = os.path.join(backliftURL, 'createsuperuser/%s')
 
     if len(args) < 1:
         parser.print_help()
@@ -467,6 +505,11 @@ def execute_command_line():
                 parser.print_help()
             else:
                 setup(args[1])
+        elif args[0].lower() == 'makesuperuser':
+            if len(args) != 3:
+                parser.print_help()
+            else:
+                make_su(options.path, args[1], args[2])
         elif args[0].lower().startswith('create'):
             if len(args) != 2:
                 parser.print_help()
